;*****************************************************************************
; Script Name:  ReptCtrl
;     Purpose:  Controls report output allowing caller to select
;               printer, screen or file as output device.
;      Author:  John C. Frykland
;               White Oak Software
;               PO Box 760
;               San Carlos, CA 94070
;               (415) 637-0222
;*****************************************************************************
;   This code is copyright (c) 1993 by White Oak Software
;
;   You may use this code in your applications without royalty
;   or consideration under the following conditions:
;
;   1.  You DO NOT copyright or claim this code as your own
;   2.  You DO NOT charge others for this code alone
;   3.  You DO include the copyright notice for all to see
;   4.  You DO hold White Oak Software and John C. Frykland
;       completely harmless from any direct, incidental or
;       other damages resulting from the use of this code.
;
;   Method of Use:
;   1.  Compile procs into your own library
;
;   2.  Call wosPutReport() to control report output
;       using following parameters:
;       a. TblName - name of table containing report data (required)
;       b.  RptNum - Paradox report number to output (required)
;       c.  OrigDevice - default output device (optional)
;           If OrigDevice is supplied, must be "Printer" "Screen" or "File"
;           Destination dialog box will NOT be displayed
;           If OrigDevice is omitted, user will be prompted for
;           report destination (Printer, Screen, File)
;       d.  FileName - name of file if printing to a file (optional)
;           If FileName is supplied, destination dialog box will
;           contain this file name as the default
;           If FileName is omitted, destination dialog box will
;           contain a blank file name
;
;*****************************************************************************

;-----------------------------------------------------------------------------
; procedure:   wosPutReport
; description: Control output of specified report
; arguments:   TblName - name of table to report on
;              RptNum - number of report to output
;              OrigDevice - default output device
;              FileName - name of file if print to file
; returns:     none
;-----------------------------------------------------------------------------
PROC wosPutReport(TblName, RptNum, OrigDevice, FileName)
    Private WorkDevice, ButtonText, Choice, rVal

    ButtonText = "~O~k"
    FileName = Upper(FileName)
    While TRUE
        If OrigDevice = "" then
            WorkDevice = wosGetRptDest(ButtonText)
        Else
            WorkDevice = OrigDevice
        EndIf
        ButtonText = "Do~A~gain"
        Switch
            Case WorkDevice = "Printer" :
                rVal = FALSE
                While TRUE
                    Message "Checking to see if printer is ready"
                    If PrinterStatus() then
                        rVal = TRUE
                        QuitLoop
                    EndIf
                    If not wosPrtRdyDlg() then
                        QuitLoop
                    EndIf
                EndWhile
                If rVal then
                    Message "Report being sent to printer.  Please wait"
                    Report TblName RptNum
                EndIf
                Message ""

            Case WorkDevice = "Screen" :
                Message "Report being sent to screen.  Please wait"
                Menu {Report} {Output}
                Select TblName
                Select RptNum
                {Screen}
                Message ""

            Case WorkDevice = "File" :
                Message "Report being sent to file.  Please wait"
                Menu {Report} {Output}
                Select TblName
                Select RptNum
                {File}
                Select FileName
                If MenuChoice() = "Cancel" then
                    {Replace}
                EndIf
                Message ""

            Case WorkDevice = "Cancel" :
                QuitLoop
        EndSwitch
        If OrigDevice <> "" then
            QuitLoop
        EndIf
    EndWhile
ENDPROC
WriteLib LibName wosPutReport
Release Procs wosPutReport

;-----------------------------------------------------------------------------
; procedure   : wosGetRptDest
; description : Prompt user for destination device for report
; arguments   : none
; returns     : Device type (Printer, Screen, File, Cancel)
;-----------------------------------------------------------------------------
PROC wosGetRptDest(OkVal)
    PRIVATE ButtonVal, DeviceNum, rVal

    ButtonVal = "Cancel"
    FileName  = ""

    SHOWDIALOG "Select Output Device"
        Proc "wosChkRptDest"
        Trigger "ACCEPT"

        @ 5,5
        HEIGHT 11 WIDTH 40

        RADIOBUTTONS
            @ 1,2
            HEIGHT 3
            WIDTH 13
            "~P~rinter",
            "~S~creen",
            "~F~ile"
            TAG "devicetype"
        TO DeviceNum

        LABEL @ 0,1
            "~D~evice"
        FOR "devicetype"

        LABEL @ 5,1
            "File ~N~ame:"
        FOR "devicetype"

        ACCEPT @ 5,12
            WIDTH 24
            "A50"
            TAG "filename"
        TO FileName

        PUSHBUTTON @ 7,3
            WIDTH 12
            OkVal
            OK DEFAULT
            VALUE "Ok"
            TAG "Ok"
        TO ButtonVal

        PUSHBUTTON @ 7,20
            WIDTH 10
            "~C~ancel"
            CANCEL
            VALUE "Cancel"
            TAG "Cancel"
        TO ButtonVal

    ENDDIALOG

    rVal = "Cancel"
    If ButtonVal = "Ok" then
        SWITCH
           CASE DeviceNum = 1 : rVal = "Printer"
           CASE DeviceNum = 2 : rVal = "Screen"
           CASE DeviceNum = 3 : rVal = "File"
        ENDSWITCH
    EndIf
    Return rVal
ENDPROC
WriteLib LibName wosGetRptDest
Release Procs wosGetRptDest

;-----------------------------------------------------------------------------
; procedure   : wosChkRptDest
; description : dialog box proc for report destination dialog box
; arguments   : standard dialog box parms
; returns     : FALSE to continue with dialog box or TRUE to end it
;-----------------------------------------------------------------------------
PROC wosChkRptDest(TriggerType, TagValue, EventValue, ElementValue)
    If TriggerType = "ACCEPT"
    and TagValue = "Ok"
    and DeviceNum = 3
    and IsBlank(FileName) then
        Message "File name required for selected report destination"
        SelectControl "filename"
        Return FALSE
    EndIf
    Return TRUE
ENDPROC
WriteLib LibName wosChkRptDest
Release Procs wosChkRptDest

;-----------------------------------------------------------------------------
; procedure   : wosPrtRdyDlg
; description : Display printer not ready dialog box
; arguments   : none
; returns     : TRUE if we check printer again or FALSE to cancel
;-----------------------------------------------------------------------------
PROC wosPrtRdyDlg()
    Private ButtonVal

    ButtonVal = ""
    SHOWDIALOG "Printer not ready"
       @2,1 HEIGHT 5 WIDTH 36

       PUSHBUTTON @1,2 WIDTH 12
          "TryAgain"
          OK
          DEFAULT
          VALUE "TryAgain"
          TAG "TryAgain"
          TO ButtonVal

       PUSHBUTTON @1,20 WIDTH 12
          "Cancel"
          CANCEL
          VALUE "Cancel"
          TAG "Cancel"
          TO ButtonVal
    ENDDIALOG

    Return (ButtonVal = "TryAgain")
ENDPROC
WriteLib LibName wosPrtRdyDlg
Release Procs wosPrtRdyDlg

;-----------------------------------------------------------------------------
; procedure   : wosLoadPrtVars
; description : Load printer control variables into memvars
; arguments   : PrinterID - Key field id of printer data to load
; returns     : TRUE if printer data loaded, else FALSE
;-----------------------------------------------------------------------------
PROC wosLoadPrtVars(PrinterID)
    Private PrtTable, rVal

    PrtTable = "PRINTERS"
    rVal = FALSE
    If IsTable(PrtTable) then
        View PrtTable
        MoveTo [Printer ID]
        Locate PrinterID
        If RetVal then
            wosPrtSize  = [PrintSize]
            wosBoldOn   = [BoldOn]
            wosBoldOff  = [BoldOff]
            wosItalOn   = [ItalicsOn]
            wosItalOff  = [ItalicsOff]
            wosUlineOn  = [UnderlineOn]
            wosUlineOff = [UnderlineOff]
            wosPorLsc   = [Portrait/Landscape]
            wosLnPerIn  = [LinesPerVertInch]
            wosTopMarg  = [TopMargin]
            wosLtMarg   = [LeftMargin]
            wosRtMarg   = [RightMargin]
            wosPgLen    = [PageLength]
            rVal = TRUE
        EndIf
        ClearImage
    EndIf
    Return rVal
ENDPROC
WriteLib LibName wosLoadPrtVars
Release Procs wosLoadPrtVars

